@@ -1,15 +1,8 @@
 package Net::OAI::Record::OAI_DC;
 
 use strict;
-use warnings;
 use base qw( XML::SAX::Base );
-use Carp qw( carp );
-our $VERSION = "1.16_12";
-
-use constant {
-  XMLNS_DC => 'http://purl.org/dc/elements/1.1/',
-  XMLNS_OAIDC => 'http://www.openarchives.org/OAI/2.0/oai_dc/',
-};
+our $VERSION = 'v1.00.0';
 
 our @OAI_DC_ELEMENTS = qw(
     title 
@@ -129,39 +122,27 @@ sub asString {
 
 sub start_element {
     my ( $self, $element ) = @_;
-    my $elname = $element->{ LocalName };
-    if ( ($element->{ NamespaceURI } eq XMLNS_OAIDC) and ($elname eq "dc") ) {
-	$self->{ _insideRecord } = 1}
-    elsif ( $element->{ NamespaceURI } ne XMLNS_DC ) {
-        carp "what is ".$element->{ Name }."?";
-        return undef;
-      }
-    elsif ( grep /$elname/, @OAI_DC_ELEMENTS ) {
-        $self->{ chars } = ""}
-    else {
-        carp "what is $elname?"}
+    if ( $element->{ Name } eq 'metadata' ) {
+	$self->{ insideMetadata } = 1;
+    }
+    $self->{ chars } = '';
 }
 
 sub end_element {
     my ( $self, $element ) = @_;
-    my $elname = $element->{ LocalName };
-
-    if ( ($element->{ NamespaceURI } eq XMLNS_OAIDC) and ($elname eq "dc") ) {
-	$self->{ _insideRecord } = 0}
-    elsif ( $element->{ NamespaceURI } ne XMLNS_DC ) {
-        return undef}
-    elsif ( grep /$elname/, @OAI_DC_ELEMENTS ) {   # o.k.
-        push( @{ $self->{ $elname } }, $self->{ chars } );
-        $self->{ chars } = undef;
-      }
-    elsif ( $self->{ chars } =~ /\S/ ) {
-        carp "unassigned content: ".$self->{ chars };
-      }
+    ## strip namespace from element name
+    my ( $elementName ) = ( $element->{ Name } =~ /^(?:.*:)?(.*)$/ );
+    if ( $elementName eq 'metadata' ) { 
+	$self->{ insideMetadata } = undef; 
+    }
+    if ( $self->{ insideMetadata } ) { 
+	push( @{ $self->{ $elementName } }, $self->{ chars } );
+    }
 }
 
 sub characters {
     my ( $self, $characters ) = @_;
-    $self->{ chars } .= $characters->{ Data } if $self->{ _insideRecord };
+    $self->{ chars } .= $characters->{ Data };
 }
 
 1;
