@@ -1,9 +1,7 @@
 package Net::OAI::ResumptionToken;
 
 use strict;
-use base qw( XML::SAX::Base );
-use Carp qw( carp );
-
+use base qw ( XML::SAX::Base );
 
 =head1 NAME
 
@@ -13,28 +11,30 @@ Net::OAI::ResumptionToken - An OAI-PMH resumption token.
 
 =head1 DESCRIPTION
 
-This SAX filter records resumption token elements.
-
 =head1 METHODS
 
 =head2 new()
 
 =cut
 
+=head2 new()
+
+=cut
+
 sub new {
     my ( $class, %opts ) = @_;
     my $self = bless \%opts, ref( $class ) || $class;
-    $self->{ _insideResumptionToken } = 0;
-    $self->{ token } = $self->{ expirationDate } = $self->{ completeListSize } = $self->{ cursor } = undef;
+    $self->{ tagStack } = [];
+    $self->{ insideResumptionToken } = 0;
+    $self->{ token } = '';
+    $self->{ expirationDate } = '';
+    $self->{ completeListSize } = '';
+    $self->{ cursor } = '';
     return( $self );
 }
 
 =head2 token()
 
-(Sets and) returns the contents of the resumptionToken element.
-
-All methods return C<undef> if no token was encountered.
-
 =cut
 
 sub token {
@@ -73,10 +73,21 @@ sub cursor {
     return( $self->{ cursor } );
 }
 
+=head1 TODO
+
+=head1 SEE ALSO
+
+=over 4
+
+=back
 
 =head1 AUTHORS
 
-Ed Summers <ehs@pobox.com>
+=over 4 
+
+=item * Ed Summers <ehs@pobox.com>
+
+=back
 
 =cut
 
@@ -84,27 +95,15 @@ Ed Summers <ehs@pobox.com>
 
 ## all children of Net::OAI::Base should call this to make sure
 ## certain object properties are set
-sub start_prefix_mapping {
-  my ($self, $mapping) = @_;
-  die "rT: self not defined" unless defined $self;
-  return $self->SUPER::start_prefix_mapping( $mapping ) if $self->get_handler();
-  die "rT: start_prefix_mapping @{[$mapping]} w/o Handler";
-}
-
 
 sub start_element { 
     my ( $self, $element ) = @_;
-    return $self->SUPER::start_element( $element ) unless $element->{NamespaceURI} eq Net::OAI::Harvester::XMLNS_OAI;
-
-    if ( $element->{ LocalName } eq 'resumptionToken' ) {
+    if ( $element->{ Name } eq 'resumptionToken' ) {
 	my $attr = $element->{ Attributes };
-	$self->{ expirationDate } = $attr->{ '{}expirationDate' }{ Value } if $attr->{ '{}expirationDate' };
-	$self->{ completeListSize } = $attr->{ '{}completeListSize' }{ Value } if $attr->{ '{}completeListSize' };
-	$self->{ cursor } = $attr->{ '{}cursor' }{ Value } if $attr->{ '{}cursor' };
-	$self->{ resumptionTokenText } = "";
-	$self->{ _insideResumptionToken } = 1;
-    } elsif ( $self->{ _insideResumptionToken } ) {
-        carp "start of unhandled subelement ".$element->{ Name }." within resumptionToken";
+	$self->{ expirationDate } = $attr->{ '{}expirationDate' }{ Value };
+	$self->{ completeListSize } = $attr->{ '{}completeListSize' }{ Value };
+	$self->{ cursor } = $attr->{ '{}cursor' }{ Value };
+	$self->{ insideResumptionToken } = 1;
     } else { 
 	$self->SUPER::start_element( $element );
     }
@@ -112,13 +111,9 @@ sub start_element {
 
 sub end_element {
     my ( $self, $element ) = @_;
-    return $self->SUPER::end_element( $element ) unless $element->{NamespaceURI} eq Net::OAI::Harvester::XMLNS_OAI;
-
-    if ( $element->{ LocalName } eq 'resumptionToken' ) {
+    if ( $element->{ Name } eq 'resumptionToken' ) {
         Net::OAI::Harvester::debug( "caught resumption token" );
-	$self->{ _insideResumptionToken } = 0;
-    } elsif ( $self->{ _insideResumptionToken } ) {
-        carp "end of unhandled subelement ".$element->{ Name }." within resumptionToken";
+	$self->{ insideResumptionToken } = 0;
     } else { 
 	$self->SUPER::end_element( $element );
     }
@@ -126,8 +121,7 @@ sub end_element {
 
 sub characters {
     my ( $self, $characters ) = @_;
-
-    if ( $self->{ _insideResumptionToken } ) {
+    if ( $self->{ insideResumptionToken } ) {
 	$self->{ resumptionTokenText } .= $characters->{ Data };
     } else { 
 	$self->SUPER::characters( $characters );
